==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/workflow/flow.md <==
checkMsgDone
===
select  count(1)
  from bas_message t, bas_message_receive m
 where t.msg_id = m.msg_id
   and t.processinstid = #processinstid#
   and ((m.deal_time > (select r.deal_time
                        from bas_message_receive r
                       where r.msg_id = #msgId#
                         and r.is_deal = 'Y'
                         and rownum = 1)and t.is_use = 'N')
         or(t.msg_title like '%撤回%') and t.sendtime>(select r.deal_time
                        from bas_message_receive r
                       where r.msg_id = #msgId#
                         and r.is_deal = 'Y'
                         and rownum = 1))
getUndoAcount
===
select distinct R.ACCOUNT_ID
  from bas_message t, bas_message_receive r
 where R.MSG_ID = T.MSG_ID
   AND t.is_use = 'Y'
   and t.processinstid = #processinstid#
@if(!isEmpty(workItemIds)){
   and t.workitemid in(select w.workitemid from  WF_WORKITEM w where  w.sourceworkitemid in(#join(workItemIds)#))
@}
getAllAcount
===
select distinct R.ACCOUNT_ID
  from bas_message t, bas_message_receive r
 where R.MSG_ID = T.MSG_ID
   and t.processinstid = #processinstid#
   and r.ACCOUNT_ID<>#accountId#
   
checkMsgPerm
===
select COUNT(1)
  from bas_message_receive r
 where r.msg_id = #msgId#
   and r.account_id = #accountId#
@if(!isEmpty(isDeal)){
	and r.is_deal = #isDeal#
@}

checkFllowWorkItemDone
===
select count(*)
  from WF_WORKITEM t
 where  t.sourceworkitemid in(#join(workItemIds)#)
   and t.processinstid = #processinstid#
 and t.currentstate in(12,7)
 
getFlowFormItem
===
select concat(f.form_name,'-',i.item_label)  text,concat('$','{',i.item_htmlname,'}') VALUE
  from gen_form_panel p, gen_panel_item i, gen_form f
 where p.panel_id = i.panel_id
   and p.form_id = f.id
   and (exists (select 1
                  from gen_FORM t
                 where t.flow_code = #flowCode#
                   and t.id = p.form_id) or exists
        (select 1
           from Gen_Form_Flow t
          where t.flow_code = #flowCode#
            and t.form_id = p.form_id))
   and p.panel_type = 0
 order by f.form_code, i.display_no
 
getAllWorkItem
===
select
	t.ACTIVITYDEFID,
	t.WORKMEMORY,
	date_format(t.ENDTIME, '%Y-%m-%d %H:%i')ENDTIME,
	getaccountname(t.PARTICIPANT) ACCOUNT_NAME 
from
	WF_WORKITEM t  where t.PROCESSINSTID =#processinstid# and t.CURRENTSTATE =12

getApproActs
===
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a
	LEFT JOIN wf_participant b ON a.workitemid = b.workitemid
	LEFT JOIN bas_roles_account c ON b.participant = concat ( c.role_id, '' ) 
WHERE a.PROCESSINSTID = #processinstid# 
	AND c.account_id = #accountId#
	AND b.partictype = 'role' 
	UNION ALL
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a
	LEFT JOIN wf_participant b ON a.workitemid = b.workitemid 
WHERE a.PROCESSINSTID = #processinstid#  
	AND b.partictype = 'person'  
	AND b.participant = #accountId#

getApproActsByBizId
===
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a,bas_message m,BAS_MESSAGE_RECEIVE r
WHERE  r.account_id = #accountId#
	and m.busi_Main_Id=#busiMainId#
	and m.form_Code=#formCode#
	AND r.msg_id = m.msg_id
	AND a.workitemid = m.workitemid
union
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a,bas_message m
WHERE  a.participant = #accountId#
	and m.busi_Main_Id=#busiMainId#
	and m.form_Code=#formCode#
	AND m.PROCESSINSTID  = a.PROCESSINSTID 

getActLastedDealPerson
===
SELECT
	a.ACCOUNT_ID participant,
	a.ACCOUNT_NAME participant2,
	'person' partic_type
FROM
	wf_workitem w,
	( SELECT max( a.ACTIVITYINSTID ) ACTIVITYINSTID FROM wf_activityinst a WHERE a.PROCESSINSTID = #processinstId# AND a.ACTIVITYDEFID = #toActId# and a.CURRENTSTATE=12 ) t,
	bas_emp_account a
WHERE
	w.ACTIVITYINSTID = t.ACTIVITYINSTID
	and a.ACCOUNT_ID = w.PARTICIPANT

==> fine-web-0.0.2-20220913.113206-173.jar: beetlsql/workflow/flow.md <==
checkMsgDone
===
select  count(1)
  from bas_message t, bas_message_receive m
 where t.msg_id = m.msg_id
   and t.processinstid = #processinstid#
   and ((m.deal_time > (select r.deal_time
                        from bas_message_receive r
                       where r.msg_id = #msgId#
                         and r.is_deal = 'Y'
                         and rownum = 1)and t.is_use = 'N')
         or(t.msg_title like '%撤回%') and t.sendtime>(select r.deal_time
                        from bas_message_receive r
                       where r.msg_id = #msgId#
                         and r.is_deal = 'Y'
                         and rownum = 1))
getUndoAcount
===
select distinct R.ACCOUNT_ID
  from bas_message t, bas_message_receive r
 where R.MSG_ID = T.MSG_ID
   AND t.is_use = 'Y'
   and t.processinstid = #processinstid#
@if(!isEmpty(workItemIds)){
   and t.workitemid in(select w.workitemid from  WF_WORKITEM w where  w.sourceworkitemid in(#join(workItemIds)#))
@}
getAllAcount
===
select distinct R.ACCOUNT_ID
  from bas_message t, bas_message_receive r
 where R.MSG_ID = T.MSG_ID
   and t.processinstid = #processinstid#
   and r.ACCOUNT_ID<>#accountId#
   
checkMsgPerm
===
select COUNT(1)
  from bas_message_receive r
 where r.msg_id = #msgId#
   and r.account_id = #accountId#
@if(!isEmpty(isDeal)){
	and r.is_deal = #isDeal#
@}

checkFllowWorkItemDone
===
select count(*)
  from WF_WORKITEM t
 where  t.sourceworkitemid in(#join(workItemIds)#)
   and t.processinstid = #processinstid#
 and t.currentstate in(12,7)
 
getFlowFormItem
===
select concat(f.form_name,'-',i.item_label)  text,concat('$','{',i.item_htmlname,'}') VALUE
  from gen_form_panel p, gen_panel_item i, gen_form f
 where p.panel_id = i.panel_id
   and p.form_id = f.id
   and (exists (select 1
                  from gen_FORM t
                 where t.flow_code = #flowCode#
                   and t.id = p.form_id) or exists
        (select 1
           from Gen_Form_Flow t
          where t.flow_code = #flowCode#
            and t.form_id = p.form_id))
   and p.panel_type = 0
 order by f.form_code, i.display_no
 
getAllWorkItem
===
select
	t.ACTIVITYDEFID,
	t.WORKMEMORY,
	date_format(t.ENDTIME, '%Y-%m-%d %H:%i')ENDTIME,
	getaccountname(t.PARTICIPANT) ACCOUNT_NAME 
from
	WF_WORKITEM t  where t.PROCESSINSTID =#processinstid# and t.CURRENTSTATE =12

getApproActs
===
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a
	LEFT JOIN wf_participant b ON a.workitemid = b.workitemid
	LEFT JOIN bas_roles_account c ON b.participant = concat ( c.role_id, '' ) 
WHERE a.PROCESSINSTID = #processinstid# 
	AND c.account_id = #accountId#
	AND b.partictype = 'role' 
	UNION ALL
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a
	LEFT JOIN wf_participant b ON a.workitemid = b.workitemid 
WHERE a.PROCESSINSTID = #processinstid#  
	AND b.partictype = 'person'  
	AND b.participant = #accountId#

getApproActsByBizId
===
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a,bas_message m,BAS_MESSAGE_RECEIVE r
WHERE  r.account_id = #accountId#
	and m.busi_Main_Id=#busiMainId#
	and m.form_Code=#formCode#
	AND r.msg_id = m.msg_id
	AND a.workitemid = m.workitemid
union
SELECT
	a.ACTIVITYDEFID 
FROM
	wf_workitem a,bas_message m
WHERE  a.participant = #accountId#
	and m.busi_Main_Id=#busiMainId#
	and m.form_Code=#formCode#
	AND m.PROCESSINSTID  = a.PROCESSINSTID 

getActLastedDealPerson
===
SELECT
	a.ACCOUNT_ID participant,
	a.ACCOUNT_NAME participant2,
	'person' partic_type
FROM
	wf_workitem w,
	( SELECT max( a.ACTIVITYINSTID ) ACTIVITYINSTID FROM wf_activityinst a WHERE a.PROCESSINSTID = #processinstId# AND a.ACTIVITYDEFID = #toActId# and a.CURRENTSTATE=12 ) t,
	bas_emp_account a
WHERE
	w.ACTIVITYINSTID = t.ACTIVITYINSTID
	and a.ACCOUNT_ID = w.PARTICIPANT	 
	
flowMonitor
===
select (select count(*) from wf_processdefine d where d.CURRENTSTATE='3') flow,
0 business,
(select count(*) from gen_form f where f.FLOW_CODE is not null and  f.IS_USE='Y') page,
(select count(*) from gen_form_flow t where t.IS_USE='Y')orgflow,
(select count(*)  from wf_workitem w where w.CURRENTSTATE=12) done,
(SELECT   count( * )    FROM wf_processinst p, stf_business_process t 
WHERE p.PROCESSINSTNAME = t.DESIGN_NAME  AND p.PROCESSINSTID IN ( SELECT m.PROCESSINSTID FROM bas_message m WHERE m.PROCESSINSTID IS NOT NULL )  
and DATE_FORMAT(p.CREATETIME,'%Y-%M-%d')=DATE_FORMAT(now(),'%Y-%M-%d')) today,
(SELECT   count( * )    FROM wf_processinst p, stf_business_process t 
WHERE p.PROCESSINSTNAME = t.DESIGN_NAME and p.CURRENTSTATE=10 AND p.PROCESSINSTID IN ( SELECT m.PROCESSINSTID FROM bas_message m WHERE m.PROCESSINSTID IS NOT NULL )  
) doing,
(SELECT   count( * )    FROM wf_processinst p, stf_business_process t 
WHERE p.PROCESSINSTNAME = t.DESIGN_NAME and p.CURRENTSTATE=12 AND p.PROCESSINSTID IN ( SELECT m.PROCESSINSTID FROM bas_message m WHERE m.PROCESSINSTID IS NOT NULL )  
) flowdone


getEdocAct
===
select t.* from 
Edoc_Acts t where t.id=#id#


checkAddWorkitem
===
SELECT group_concat(GETACCOUNTNAME(w.participant)) account_name
	FROM
		wf_workitem w ,wf_workitem_add t 
	WHERE
	t.PROCESSINSTID = #processinstId# and t.WORKITEMID=#workitemid# and t.IS_USE='Y' and w.PROCESSINSTID= t.PROCESSINSTID
	AND t.ADD_TYPE = '2' 
	and	FIND_IN_SET( w.participant, t.add_persons ) > 0 
	AND w.starttime >= t.create_time 
	AND w.CURRENTSTATE != '12'
